@@ -24,7 +24,7 @@ from zim.errors import Error
 from zim.utils import natural_sort_key
 from zim.newfs.helpers import TrashNotSupportedError
 from zim.config import HierarchicDict
-from zim.parsing import is_interwiki_keyword_re, link_type, is_win32_path_re
+from zim.parsing import link_type, is_win32_path_re
 from zim.signals import ConnectorMixin, SignalEmitter, SIGNAL_NORMAL
 
 from .operations import notebook_state, NOOP, SimpleAsyncOperation, ongoing_operation
@@ -537,35 +537,32 @@ class Notebook(ConnectorMixin, SignalEmitter):
 		if isinstance(op, SimpleAsyncOperation):
 			op()
 
-	def move_page(self, path, newpath, update_links=True):
-		'''Move a page in the notebook
+	def move_page(self, path, newpath, update_links=True, update_heading=False):
+		'''Move and/or rename a page in the notebook
 
 		@param path: a L{Path} object for the old/current page name
 		@param newpath: a L{Path} object for the new page name
 		@param update_links: if C{True} all links B{from} and B{to} this
 		page and any of it's children will be updated to reflect the
 		new page name
+		@param update_heading: if C{True} the heading of the page will be
+		changed to the basename of the new path
 
 		The original page C{path} does not have to exist, in this case
 		only the link update will done. This is useful to update links
 		for a placeholder.
 
-		Where:
-		  - C{page} is the L{Page} object for the page being updated
-		  - C{total} is an optional parameter for the number of pages
-		    still to go - if known
-
 		@raises PageExistsError: if C{newpath} already exists
 
 		@emits: move-page before the move
-		@emits: moved-page after succesful move
+		@emits: moved-page after successfull move
 		'''
-		for p in self.move_page_iter(path, newpath, update_links):
+		for p in self.move_page_iter(path, newpath, update_links, update_heading):
 			pass
 
 	@assert_index_uptodate
 	@notebook_state
-	def move_page_iter(self, path, newpath, update_links=True):
+	def move_page_iter(self, path, newpath, update_links=True, update_heading=False):
 		'''Like L{move_page()} but yields pages that are being updated
 		if C{update_links} is C{True}
 		'''
@@ -576,14 +573,18 @@ class Notebook(ConnectorMixin, SignalEmitter):
 			n_links = self.links.n_list_links_section(path, LINK_DIR_BACKWARD)
 		except IndexNotFoundError:
 			raise PageNotFoundError(path)
-		self._move_file_and_folder(path, newpath)
-		self.flush_page_cache(path)
-		self.emit('moved-page', path, newpath)
+
+		file, folder = self.layout.map_page(path)
+		if (file.exists() or folder.exists()):
+			self._move_file_and_folder(path, newpath)
+			self.flush_page_cache(path)
+			self.emit('moved-page', path, newpath)
+
+			if update_links:
+				for p in self._update_links_in_moved_page(path, newpath):
+					yield p
 
 		if update_links:
-			for p in self._update_links_in_moved_page(path, newpath):
-				yield p
-
 			for p in self._update_links_to_moved_page(path, newpath):
 				yield p
 
@@ -593,6 +594,14 @@ class Notebook(ConnectorMixin, SignalEmitter):
 			else:
 				logger.debug('Number of links after move does match number before move (%i)', new_n_links)
 
+		if update_heading:
+			page = self.get_page(newpath)
+			tree = page.get_parsetree()
+			if not tree is None:
+				tree.set_heading_text(newpath.basename)
+				page.set_parsetree(tree)
+				self.store_page(page)
+
 	def _move_file_and_folder(self, path, newpath):
 		file, folder = self.layout.map_page(path)
 		if not (file.exists() or folder.exists()):
@@ -793,56 +802,6 @@ class Notebook(ConnectorMixin, SignalEmitter):
 		elt.set('href', text)
 		return elt
 
-	def rename_page(self, path, newbasename, update_heading=True, update_links=True):
-		'''Rename page to a page in the same namespace but with a new
-		basename.
-
-		This is similar to moving within the same namespace, but
-		conceptually different in the user interface. Internally
-		L{move_page()} is used here as well.
-
-		@param path: a L{Path} object for the old/current page name
-		@param newbasename: new name as string
-		@param update_heading: if C{True} the first heading in the
-		page will be updated to the new name
-		@param update_links: if C{True} all links B{from} and B{to} this
-		page and any of it's children will be updated to reflect the
-		new page name
-
-		@emits: move-page before the move
-		@emits: moved-page after succesful move
-		'''
-		newbasename = Path.makeValidPageName(newbasename)
-		newpath = Path(path.namespace + ':' + newbasename)
-
-		for p in self.rename_page_iter(path, newbasename, update_heading, update_links):
-			pass
-
-		return newpath
-
-	@assert_index_uptodate
-	@notebook_state
-	def rename_page_iter(self, path, newbasename, update_heading=True, update_links=True):
-		'''Like L{rename_page()} but yields pages that are being updated
-		if C{update_links} is C{True}
-		'''
-		logger.debug('Rename %s to "%s" (%s, %s)',
-			path, newbasename, update_heading, update_links)
-
-		newbasename = Path.makeValidPageName(newbasename)
-		newpath = Path(path.namespace + ':' + newbasename)
-
-		for p in self.move_page_iter(path, newpath, update_links):
-			yield p
-
-		if update_heading:
-			page = self.get_page(newpath)
-			tree = page.get_parsetree()
-			if not tree is None:
-				tree.set_heading(newbasename)
-				page.set_parsetree(tree)
-				self.store_page(page)
-
 	@assert_index_uptodate
 	@notebook_state
 	def delete_page(self, path, update_links=True):
@@ -858,7 +817,7 @@ class Notebook(ConnectorMixin, SignalEmitter):
 		Raises an error when delete failed.
 
 		@emits: delete-page before the actual delete
-		@emits: deleted-page after succesful deletion
+		@emits: deleted-page after successfull deletion
 		'''
 		existed = self._delete_page(path)
 
@@ -922,7 +881,7 @@ class Notebook(ConnectorMixin, SignalEmitter):
 		for this notebook.
 
 		@emits: delete-page before the actual delete
-		@emits: deleted-page after succesful deletion
+		@emits: deleted-page after successfull deletion
 		'''
 		existed = self._trash_page(path)
 
